@@ -1,7 +1,7 @@
 get.rhea.all <-
 function() {
 	
-	url = "ftp://ftp.ebi.ac.uk/pub/databases/rhea/biopax/rhea-biopax.owl.gz"
+	url = "ftp://ftp.ebi.ac.uk/pub/databases/rhea/biopax//rhea-biopax_full.owl.gz"
 	tmpdest = tempfile(pattern = "rhea")
 	download.file(url, destfile = tmpdest)
 	owl = readLines(tmpdest)
